==> jc-1.4.0.tar.gz: java/awt/Scrollbar__24AccessibleAWTScrollBar.h <==
// public class java.awt.Scrollbar$AccessibleAWTScrollBar

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class a32ca3ecc522c1be java_awt_Scrollbar__24AccessibleAWTScrollBar
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_
#define _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_

// Forward structure declarations
struct _jc_java_awt_Scrollbar$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;

// Typedefs
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object;

typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype;

// Class fields structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$class_fields;

// Constructors
extern void _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$_init$f7a2d2908cec4e5e(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_awt_Scrollbar$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern struct _jc_object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
extern jboolean _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_lang_Number$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *);
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_lang_Number$object *);
};

// Vtable
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods	java_awt_Scrollbar__24AccessibleAWTScrollBar;
};

// Vtype
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype {
	_jc_type			type;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs {
	struct _jc_java_awt_Scrollbar$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs {
    _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs	java_awt_Scrollbar__24AccessibleAWTScrollBar;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs	java_awt_Scrollbar__24AccessibleAWTScrollBar;
};

// Object instance structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object {
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype	*vtype;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Scrollbar__24AccessibleAWTScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$class_object;

#endif	/* _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_ */

==> jc-1.4.5.tar.gz: java/awt/Scrollbar__24AccessibleAWTScrollBar.h <==
// public class java.awt.Scrollbar$AccessibleAWTScrollBar

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class a32ca3ecc522c1be java_awt_Scrollbar__24AccessibleAWTScrollBar
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_
#define _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_

// Forward structure declarations
struct _jc_java_awt_Scrollbar$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;

// Typedefs
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs;
typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object;

typedef struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable;
typedef const struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype;

// Class fields structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$fields_struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$class_fields;

// Constructors
extern void _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$_init$f7a2d2908cec4e5e(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_awt_Scrollbar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *) _JC_JCNI_ATTR;
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vmethods	java_awt_Scrollbar__24AccessibleAWTScrollBar;
};

// Vtype
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype {
	_jc_type			type;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs {
	struct _jc_java_awt_Scrollbar$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs {
    _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_refs	java_awt_Scrollbar__24AccessibleAWTScrollBar;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$sub_nonrefs	java_awt_Scrollbar__24AccessibleAWTScrollBar;
};

// Object instance structure
struct _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$object {
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype	*vtype;
	_jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$vtype _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Scrollbar__24AccessibleAWTScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Scrollbar__24AccessibleAWTScrollBar$class_object;

#endif	/* _JC_java_awt_Scrollbar__24AccessibleAWTScrollBar_H_ */
